#
# spec file for package python-siphashc
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2017 Matthias Fehring <buschmann23@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-siphashc
Version:        2.5
Release:        1.5
Summary:        Python C module to calculate SipHashes
License:        ISC
Group:          Development/Languages/Python
URL:            https://github.com/WeblateOrg/siphashc
Source:         https://files.pythonhosted.org/packages/source/s/siphashc/siphashc-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Obsoletes:      python-siphashc3 < %{version}
Provides:       python-siphashc3 = %{version}
%python_subpackages

%description
A Python C module for siphash. SipHash is an add–rotate–xor (ARX)
based family of pseudorandom functions.

SipHash is fundamentally different from cryptographic hash functions
like SHA in that SipHash is only suitable as a message authentication
code.

%prep
%setup -q -n siphashc-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%check
%pytest_arch

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%files %{python_files}
%license LICENSE.md
%doc README.rst CHANGES.rst
%{python_sitearch}/*

%changelog
* Sat Nov  9 2024 Dirk Müller <dmueller@suse.com>
- update to 2.5:
  * Python 3.13 compatiblity.
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 2.4.1:
  * Added type annotations
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 2.3:
  * Tested with Python 3.9, 3.10, 3.11, and 3.12, no changes
    needed.
  * Dropped support for Python 3.5, 3.6, and 3.7.
* Sat Jul  1 2023 Markéta Machová <mmachova@suse.com>
- Update to 2.1 (also from 2020)
  * Dropped support for Python 2.
* Wed Jun  3 2020 pgajdos@suse.com
- use %%pytest macro
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Drop unused unittest2 dependency
* Mon Jan  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.3:
  * Changed license to ISC.
  * Fixed depreciation warning on Python 3.8.
* Sun Feb 24 2019 John Vandenberg <jayvdb@gmail.com>
- Remove nose custom test runner and unittest2 on Python 3
- Added CHANGES.rst to docs
- Add missing Provides to accompany Obsoletes
- Add CFLAGS="%%{optflags}"
- Update to v1.2
  * Included tests in the pypi package.
- from v1.1
  * Fixed README encoding.
  * Included documentation in the pypi package.
* Wed Aug  8 2018 jengelh@inai.de
- Fix irrelevant description.
* Wed Aug  1 2018 tchvatal@suse.com
- Install license file
- Make sure tests are run
* Wed Oct 25 2017 buschmann23@opensuse.org
- obsolete python-siphashc3
* Wed Oct 25 2017 buschmann23@opensuse.org
- initial package
